'use strict';
const selectedMovie = document.getElementById('movies');
const movieSeats = document.querySelector('.movieSeats');
const infoModal = document.getElementById('info');
let availableSeats = [
  ...document.querySelector('.movieSeats').querySelectorAll('li:not(.occupied)')
];
const count = document.getElementById('count');
const total = document.getElementById('total');
const closeButton = document.querySelector('.close-button');
const buttonClear = document.querySelector('.clear');
const buttonBook = document.querySelector('.book');
let ticketPrice = +selectedMovie.value;

//Save selected movie index and price
const setMovieData = (movieIndex, moviePrice) => {
  localStorage.setItem('selectedMovieIndex', movieIndex);
  localStorage.setItem('selectedMoviePrice', moviePrice);
};

//Seat click event
movieSeats.addEventListener('click', e => {
  if (
    e.target.classList.contains('radius') &&
    !e.target.classList.contains('occupied')
  ) {
    e.target.classList.toggle('selected');
    updateSelectedSeats();
  }
});

//Movie select event
selectedMovie.addEventListener('change', e => {
  ticketPrice = +e.target.value;
  setMovieData(e.target.selectedIndex, e.target.value);
  updateSelectedSeats();
});

//Update total and count
const updateSelectedSeats = () => {
  let arrayOfSeatsSelected = document
    .querySelector('.movieSeats')
    .querySelectorAll('li.selected');

  const seatsIndex = [...arrayOfSeatsSelected].map(seat =>
    [...arrayOfSeatsSelected].indexOf(seat)
  );

  let numberOfSeats = arrayOfSeatsSelected.length;
  let totalPrice = arrayOfSeatsSelected.length * ticketPrice;
  count.innerText = numberOfSeats;
  total.innerText = totalPrice;
  saveToLocalStorage(numberOfSeats, totalPrice, seatsIndex);
};

//Save to local storage
const saveToLocalStorage = (numberOfSeats, totalPrice, seatsIndex) => {
  localStorage.setItem('numberOfSeats', numberOfSeats);
  localStorage.setItem('ticketPrice', totalPrice);
  localStorage.setItem('selectedSeats', JSON.stringify(seatsIndex));
};

(() => {
  const selectedSeats = JSON.parse(localStorage.getItem('selectedSeats'));
  if (localStorage.length > 0) {
    availableSeats.forEach((seat, index) => {
      if (selectedSeats.indexOf(index) > -1) {
        seat.classList.add('selected');
      }
    });

    count.innerText = localStorage.getItem('numberOfSeats');
    total.innerText = localStorage.getItem('ticketPrice');

    const selectedMovieIndex = localStorage.getItem('selectedMovieIndex');

    if (selectedMovieIndex !== null) {
      selectedMovie.selectedIndex = selectedMovieIndex;
    }
  }
})();

//Clear localStorage
const clear = () => {
  localStorage.clear();
  count.innerText = '0';
  total.innerText = '0';
  selectedMovie.selectedIndex = '';

  availableSeats.forEach(o => {
    o.classList.remove('selected');
  });
};

//Show modal with booking info
const showModal = () => {
  const numberOfSeats = localStorage.getItem('numberOfSeats');
  if (numberOfSeats > 0) {
    infoModal.classList.toggle('popup');
  }
};

buttonClear.addEventListener('click', clear);
buttonBook.addEventListener('click', showModal);
closeButton.addEventListener('click', showModal);
