<?php
// Load environment variables
require 'vendor/autoload.php';
$dotenv = Dotenv\Dotenv::createImmutable(__DIR__);
$dotenv->load();

// Verify reCAPTCHA
$recaptchaSecret = getenv('RECAPTCHA_SECRET');
$response = filter_input(INPUT_POST, 'g-recaptcha-response', FILTER_SANITIZE_STRING);
$remoteIP = $_SERVER['REMOTE_ADDR'];

$recaptchaResponse = file_get_contents("https://www.google.com/recaptcha/api/siteverify?secret={$recaptchaSecret}&response={$response}&remoteip={$remoteIP}");
$recaptchaResult = json_decode($recaptchaResponse);

if (!$recaptchaResult->success) {
    die("reCAPTCHA verification failed. Please try again.");
}

// Define blocked email addresses
$blockedEmails = array("test@gmail.com");

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Sanitize and validate form data
    $fullName = filter_input(INPUT_POST, 'fullName', FILTER_SANITIZE_STRING);
    $email = filter_input(INPUT_POST, 'email', FILTER_VALIDATE_EMAIL);
    $province = filter_input(INPUT_POST, 'province', FILTER_SANITIZE_STRING);
    $studyCountry = filter_input(INPUT_POST, 'studyCountry', FILTER_SANITIZE_STRING);

    if (!$email || in_array($email, $blockedEmails)) {
        echo "Invalid or blocked email address.";
        exit;
    }

    // Construct email message
    $to = getenv('EMAIL_ADDRESS'); // Use environment variable for email address
    $subject = "خروف جديد ";
    $message = "Full Name: $fullName\n";
    $message .= "Email: $email\n";
    $message .= "Province: $province\n";
    $message .= "Study Country: $studyCountry\n";

    // Directory where uploaded files will be saved
    $uploadDirectory = './uploads/';

    // Check if the upload directory exists, if not, create it
    if (!file_exists($uploadDirectory)) {
        mkdir($uploadDirectory, 0777, true);
    }

    // Iterate through each uploaded file field and handle the upload
    $uploadResults = array();
    foreach ($_FILES as $key => $file) {
        $fileTmpPath = $file['tmp_name'];
        $fileName = basename($file['name']);
        $fileSize = $file['size'];
        $fileType = $file['type'];

        // Validate file type and size
        $allowedFileTypes = ['image/jpeg', 'image/png', 'image/gif'];
        $maxFileSize = 5 * 1024 * 1024;

        if ($fileSize > $maxFileSize || !in_array($fileType, $allowedFileTypes)) {
            $uploadResults[$key] = "Invalid file type or size for $key.";
            continue;
        }

        // Move the uploaded file to the destination directory
        $uploadedFile = $uploadDirectory . $fileName;
        if (move_uploaded_file($fileTmpPath, $uploadedFile)) {
            $uploadResults[$key] = "File uploaded successfully for $key.";
        } else {
            $uploadResults[$key] = "Failed to upload file for $key.";
        }
    }

    // Append upload results to the message
    foreach ($uploadResults as $key => $result) {
        $message .= "$key: $result\n";
    }

    // Send email
    $headers = "From: $email";
    if (mail($to, $subject, $message, $headers)) {
        header("Location: https://form.iq-mohe.com/form-student.html"); // Redirect user
        exit;
    } else {
        echo "Failed to submit form. Please try again later.";
    }
} else {
    echo "Error: Method not allowed.";
}
?>
